@@ -14,6 +14,7 @@ use git_cliff_core::release::*;
 use git_cliff_core::template::Template;
 use pretty_assertions::assert_eq;
 use regex::Regex;
+use std::collections::HashMap;
 use std::fmt::Write;
 
 #[test]
@@ -22,7 +23,7 @@ fn generate_changelog() -> Result<()> {
 		header:         Some(String::from("this is a changelog")),
 		body:           Some(String::from(
 			r#"
-## Release {{ version }}
+## Release {{ version }} - <DATE>
 {% for group, commits in commits | group_by(attribute="group") %}
 ### {{ group }}
 {% for commit in commits %}
@@ -52,6 +53,18 @@ fn generate_changelog() -> Result<()> {
 		}]),
 		commit_parsers:           Some(vec![
 			CommitParser {
+				sha:           Some(String::from("coffee")),
+				message:       None,
+				body:          None,
+				group:         Some(String::from("I love coffee")),
+				default_scope: None,
+				scope:         None,
+				skip:          None,
+				field:         None,
+				pattern:       None,
+			},
+			CommitParser {
+				sha:           None,
 				message:       Regex::new("^feat").ok(),
 				body:          None,
 				group:         Some(String::from("shiny features")),
@@ -62,6 +75,7 @@ fn generate_changelog() -> Result<()> {
 				pattern:       None,
 			},
 			CommitParser {
+				sha:           None,
 				message:       Regex::new("^fix").ok(),
 				body:          None,
 				group:         Some(String::from("fix bugs")),
@@ -72,6 +86,7 @@ fn generate_changelog() -> Result<()> {
 				pattern:       None,
 			},
 			CommitParser {
+				sha:           None,
 				message:       Regex::new("^test").ok(),
 				body:          None,
 				group:         None,
@@ -82,6 +97,7 @@ fn generate_changelog() -> Result<()> {
 				pattern:       None,
 			},
 			CommitParser {
+				sha:           None,
 				message:       None,
 				body:          None,
 				group:         Some(String::from("docs")),
@@ -129,6 +145,7 @@ fn generate_changelog() -> Result<()> {
 		Release {
 			version:   Some(String::from("v2.0.0")),
 			commits:   vec![
+
 				Commit::new(
 					String::from("000abc"),
 					String::from("Add unconventional commit"),
@@ -171,6 +188,10 @@ fn generate_changelog() -> Result<()> {
 			commit_id: None,
 			timestamp: 0,
 			previous:  None,
+			#[cfg(feature = "github")]
+			github: git_cliff_core::github::GitHubReleaseMetadata {
+				contributors: vec![],
+			},
 		},
 		Release {
 			version:   Some(String::from("v1.0.0")),
@@ -195,22 +216,39 @@ fn generate_changelog() -> Result<()> {
 			commit_id: None,
 			timestamp: 0,
 			previous:  None,
+			#[cfg(feature = "github")]
+			github: git_cliff_core::github::GitHubReleaseMetadata {
+				contributors: vec![],
+			},
 		},
 	];
 
 	let out = &mut String::new();
-	let template = Template::new(changelog_config.body.unwrap())?;
+	let template = Template::new(changelog_config.body.unwrap(), false)?;
 
 	writeln!(out, "{}", changelog_config.header.unwrap()).unwrap();
 	for release in releases {
-		write!(out, "{}", template.render(&release)?).unwrap();
+		write!(
+			out,
+			"{}",
+			template.render(
+				&release,
+				Option::<HashMap<&str, String>>::None.as_ref(),
+				&[TextProcessor {
+					pattern:         Regex::new("<DATE>").unwrap(),
+					replace:         Some(String::from("2023")),
+					replace_command: None,
+				}]
+			)?
+		)
+		.unwrap();
 	}
 	writeln!(out, "{}", changelog_config.footer.unwrap()).unwrap();
 
 	assert_eq!(
 		r#"this is a changelog
 
-## Release v2.0.0
+## Release v2.0.0 - 2023
 
 ### docs
 - *(cool)* testing author filtering
@@ -229,7 +267,7 @@ fn generate_changelog() -> Result<()> {
 ### test
 - *(tests)* test some stuff
 
-## Release v1.0.0
+## Release v1.0.0 - 2023
 
 ### chore
 - do nothing
